
local make_fine_text = function(text)
	local x, y, w, h = text:text_rect()
	text:set_size(w, h)
	text:set_position(math.round(text:x()), math.round(text:y()))
end

MenuNodeCrimenetChallengeNewGui = MenuNodeCrimenetChallengeNewGui or class(MenuNodeCrimenetChallengeGui)
MenuNodeCrimenetChallengeNewGui.WIDTH = 740
MenuNodeCrimenetChallengeNewGui.HEIGHT = 442
MenuNodeCrimenetChallengeNewGui.MENU_WIDTH = 240
MenuNodeCrimenetChallengeNewGui.PADDING = 10
MenuNodeCrimenetChallengeNewGui.CODEX_TEXT_ID = "menu_cn_challenge_title_new"

function MenuNodeCrimenetChallengeNewGui:init(...)
	MenuNodeCrimenetChallengeNewGui.super.init(self, ...)
	managers.menu_component:disable_main_menu()
end

function MenuNodeCrimenetChallengeNewGui:close(...)
	MenuNodeCrimenetChallengeNewGui.super.close(self, ...)
	managers.menu_component:enable_main_menu()
end

function MenuNodeCrimenetChallengeNewGui:_set_panel_position(panel)
	self._panel:set_right(panel:w())
	self._panel:set_top(172)
end

function MenuNodeCrimenetChallengeNewGui:_setup_blur()
	local full_scaled_size = managers.gui_data:full_16_9_size()
	local blur = self._fullscreen_panel:bitmap({
		texture = "guis/textures/test_blur_df",
		render_template = "VertexColorTexturedBlur3D"
	})
	blur:set_world_shape(self._panel:world_shape())
	blur:move(full_scaled_size.convert_x, full_scaled_size.convert_y)
	local func = function(o)
		local start_blur = 0
		over(0.6, function(p)
			o:set_alpha(math.lerp(start_blur, 1, p))
		end)
	end
	blur:animate(func)
end

function MenuNodeCrimenetChallengeNewGui:_setup_item_panel_parent(safe_rect, shape)
	local x = safe_rect.x + safe_rect.width - self.WIDTH + self.PADDING
	local y = safe_rect.y + safe_rect.height - self.HEIGHT + self.PADDING - 60
	shape = shape or {}
	shape.x = shape.x or x
	shape.y = shape.y or y
	shape.w = shape.w or self.MENU_WIDTH
	shape.h = shape.h or self.HEIGHT - 2 * self.PADDING - tweak_data.menu.pd2_small_font_size
	MenuNodeCrimenetChallengeNewGui.super.super._setup_item_panel_parent(self, safe_rect, shape)
end

function MenuNodeCrimenetChallengeNewGui:_setup_menu()
	if not self._init_finish then
		return
	end
	MenuNodeCrimenetChallengeNewGui.super._setup_menu(self)
	if alive(self.ws:panel():child("main_panel"):child("title_text")) then
		local title_text = self.ws:panel():child("main_panel"):child("title_text")
		local bottom = title_text:bottom()
		title_text:set_font(Idstring(tweak_data.menu.pd2_large_font))
		title_text:set_font_size(tweak_data.menu.pd2_large_font_size)
		make_fine_text(title_text)
		title_text:set_bottom(bottom)
	end
	if self._back_row_item and alive(self._back_row_item.gui_text) then
		self._back_row_item.gui_text:set_w(self:_scaled_size().width * 0.35)
		self._back_row_item.gui_text:set_world_right(math.round(self.ws:panel():w()))
		self._back_row_item.gui_text:set_world_bottom(math.round(self.ws:panel():h()))
		if not self._back_item_bg and MenuBackdropGUI and managers.menu:is_pc_controller() then
			local bg_text = self._back_row_item.gui_pd2_panel:text({
				text = utf8.to_upper(self._back_row_item.text),
				h = 90,
				align = "right",
				vertical = "bottom",
				font_size = tweak_data.menu.pd2_massive_font_size,
				font = tweak_data.menu.pd2_massive_font,
				color = tweak_data.screen_colors.button_stage_3,
				alpha = 0.4,
				layer = -1,
				rotation = 360
			})
			bg_text:set_right(self._back_row_item.gui_text:right())
			bg_text:set_center_y(self._back_row_item.gui_text:center_y())
			bg_text:move(13, -9)
			self._back_item_bg = true
			MenuBackdropGUI.animate_bg_text(self, bg_text)
		end
	end
end

function MenuNodeCrimenetChallengeNewGui:gui_node_custom(row_item)
	row_item.gui_panel = self._item_panel_parent:panel({
		layer = self.layers.items,
		w = 3,
		h = 3
	})
	row_item.gui_pd2_panel = self.ws:panel():panel({
		layer = self.layers.items
	})
	local row_item_panel = row_item.gui_pd2_panel
	row_item.gui_text = row_item_panel:text({
		font_size = tweak_data.menu.pd2_large_font_size,
		x = 0,
		y = 0,
		align = "right",
		vertical = "bottom",
		font = tweak_data.menu.pd2_large_font,
		color = tweak_data.screen_colors.button_stage_3,
		layer = 0,
		text = utf8.to_upper(row_item.text),
		blend_mode = "add",
		render_template = Idstring("VertexColorTextured")
	})
	local _, _, w, h = row_item.gui_text:text_rect()
	row_item.gui_text:set_size(math.round(w), math.round(h))
	self._back_row_item = row_item
	self._back_item_bg = false
end

function MenuNodeCrimenetChallengeNewGui:_align_marker(row_item)
	MenuNodeCrimenetChallengeGui.super.super._align_marker(self, row_item)
	if row_item.item:parameters().pd2_corner then
		self._marker_data.marker:set_visible(true)
		self._marker_data.gradient:set_visible(true)
		self._marker_data.gradient:set_rotation(360)
		self._marker_data.marker:set_height(64 * row_item.gui_text:height() / 32)
		self._marker_data.gradient:set_height(64 * row_item.gui_text:height() / 32)
		self._marker_data.marker:set_w(self:_scaled_size().width * 0.35)
		self._marker_data.gradient:set_w(self._marker_data.marker:w())
		self._marker_data.marker:set_world_right(row_item.gui_text:world_right())
		self._marker_data.marker:set_world_center_y(row_item.gui_text:world_center_y() - 2)
		return
	end
end